@@ -38,6 +38,14 @@ my %lang_alias = (
     'pt_BR'     => 'portuguese',
     'br'        => 'portuguese',
 
+    'no'        => 'norwegian',
+
+    'es'        => 'spanish',
+
+    'tr'        => 'tukish',
+
+    'cn'        => 'chinese',
+
 );
 
 sub new()
